==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/OperatorHubBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorHubBuilder extends io.fabric8.openshift.api.model.OperatorHubFluentImpl<io.fabric8.openshift.api.model.OperatorHubBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.OperatorHub,io.fabric8.openshift.api.model.OperatorHubBuilder>{
  public OperatorHubBuilder() {
    this(false);
  }
  public OperatorHubBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorHub(), validationEnabled);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorHub(), validationEnabled);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHub instance) {
    this(fluent, instance, false);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHub instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHub instance) {
    this(instance,false);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHub instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.OperatorHub build() {
    OperatorHub buildable = new OperatorHub(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorHubBuilder that = (OperatorHubBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/OperatorHubBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorHubBuilder extends io.fabric8.openshift.api.model.OperatorHubFluentImpl<io.fabric8.openshift.api.model.OperatorHubBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.OperatorHub,io.fabric8.openshift.api.model.OperatorHubBuilder>{
  public OperatorHubBuilder() {
    this(false);
  }
  public OperatorHubBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorHub(), validationEnabled);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorHub(), validationEnabled);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHub instance) {
    this(fluent, instance, false);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHub instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHub instance) {
    this(instance,false);
  }
  public OperatorHubBuilder(io.fabric8.openshift.api.model.OperatorHub instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.OperatorHubFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.OperatorHub build() {
    OperatorHub buildable = new OperatorHub(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorHubBuilder that = (OperatorHubBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
